@@ -8,19 +8,17 @@ import org.gcube.portlets.user.td.columnwidget.client.dimension.ConnectCodelistD
 import org.gcube.portlets.user.td.columnwidget.client.dimension.ConnectCodelistListener;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionDialog;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionListener;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ShowOccurrencesTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.store.ShowOccurrencesTypeElement;
 import org.gcube.portlets.user.td.columnwidget.client.store.ShowOccurrencesTypeStore;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.task.InvocationS;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnViewData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ConditionCode;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.RefColumn;
@@ -35,6 +33,8 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestProperties;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestPropertiesParameterType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnViewData;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.cell.client.AbstractCell;
