@@ -2,15 +2,15 @@ package org.gcube.portlets.user.td.columnwidget.client.dimension;
 
 import java.util.ArrayList;
 
-import org.gcube.portlets.user.td.columnwidget.client.utils.Constants;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.Constants;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 import org.gcube.portlets.user.tdwx.client.TabularDataX;
 import org.gcube.portlets.user.tdwx.client.TabularDataXGridPanel;
 import org.gcube.portlets.user.tdwx.client.event.FailureEvent;
-import org.gcube.portlets.user.tdwx.client.event.FailureEventHandler;
+import org.gcube.portlets.user.tdwx.client.event.FailureEvent.FailureEventHandler;
 import org.gcube.portlets.user.tdwx.shared.StaticFilterInformation;
 import org.gcube.portlets.user.tdwx.shared.model.TableId;
 
@@ -257,13 +257,13 @@ public class DimensionRowSelectionDialog extends Window {
 					tableId = Long.valueOf(column.getRelationship()
 							.getTargetTableId());
 				} else {
-					
-					UtilsGXT3.alert("Attention",
-							"No valid table associated with this column!");
+					UtilsGXT3
+							.alert("Attention",
+									"No valid relationship associated with this column!");
 					hide();
 					return;
-
 				}
+
 			}
 		}
 
